.. _index:

=======================================================
hgvs -- Parse, Format, and Manipulate Sequence Variants
=======================================================

.. sidebar:: Quick Links

  | `BitBucket Repo <https://bitbucket.org/invitae/hgvs>`_
  | `Documentation <http://pythonhosted.org/hgvs/>`_
  .. image:: https://drone.io/bitbucket.org/invitae/hgvs/status.png

Contents
--------

.. toctree::
   :maxdepth: 2

   overview
   installation
   getting_started
   developer
   classes

   reST-examples


Additional Resources
--------------------

* UTA, BDI

* `HGVS Recommendations`_
* Laros

.. _`HGVS Recommendations`: http://www.hgvs.org/mutnomen/


License
-------

hgvs is released under the `Apache License 2.0
<http://www.apache.org/licenses/LICENSE-2.0>`_.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

